==> plasma-framework-5.111.0.tar.xz: plasma-framework-5.111.0/src/desktoptheme/air/metadata.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "kde-artists@kde.org",
                "Name": "The Oxygen Project",
                "Name[az]": "Oxygen layihəsi",
                "Name[be]": "Праект \"Oxygen\"",
                "Name[bg]": "Проектът Oxygen",
                "Name[ca@valencia]": "The Oxygen Project",
                "Name[ca]": "The Oxygen Project",
                "Name[cs]": "Projekt Oxygen",
                "Name[en_GB]": "The Oxygen Project",
                "Name[eo]": "La Oksigeno-Projekto",
                "Name[es]": "El proyecto Oxígeno",
                "Name[eu]": "«Oxygen» proiektua",
                "Name[fi]": "Oxygen-projekti",
                "Name[fr]": "Le projet « Oxygen »",
                "Name[gl]": "O proxecto Osíxeno",
                "Name[ia]": "Le projecto Oxigen",
                "Name[id]": "The Oxygen Project",
                "Name[it]": "Il progetto Oxygen",
                "Name[ka]": "The Oxygen Project",
                "Name[ko]": "The Oxygen Project",
                "Name[nl]": "Het project Oxygen",
                "Name[nn]": "Oxygen-prosjektet",
                "Name[pl]": "Projekt Tlenu",
                "Name[pt]": "O Projecto Oxygen",
                "Name[pt_BR]": "O projeto Oxygen",
                "Name[ru]": "Проект Oxygen",
                "Name[sl]": "Projekt kisik",
                "Name[sv]": "Oxygen-projektet",
                "Name[tr]": "Oksijen Projesi",
                "Name[uk]": "Проєкт Oxygen",
                "Name[vi]": "Dự án Oxygen",
                "Name[x-test]": "xxThe Oxygen Projectxx",
                "Name[zh_CN]": "Oxygen 项目"
            }
        ],
        "Category": "",
        "Description": "A breath of fresh air",
        "Description[az]": "Bir nəfəs təmiz hava",
        "Description[be]": "Глыток свежага паветра",
        "Description[bg]": "Глътка свеж въздух",
        "Description[ca@valencia]": "Una alenada d'aire fresc",
        "Description[ca]": "Una alenada d'aire fresc",
        "Description[cs]": "Závan čerstvého vzduchu",
        "Description[en_GB]": "A breath of fresh air",
        "Description[eo]": "Spiro de freŝa aero",
        "Description[es]": "Un soplo de aire fresco",
        "Description[eu]": "Haize freskoa arnastea",
        "Description[fi]": "Raikkaan ilman henkäys",
        "Description[fr]": "Une bouffée d'air frais",
        "Description[gl]": "Un folgo de ar fresco.",
        "Description[ia]": "Un respiration de aere fresc",
        "Description[id]": "A breath of fresh air",
        "Description[it]": "Una ventata di aria fresca",
        "Description[ka]": "სუფთა ჰაერის ჩასუნთქვა",
        "Description[ko]": "신선한 바람",
        "Description[nl]": "Een hap frisse lucht",
        "Description[nn]": "Eit friskt pust",
        "Description[pl]": "Powiew świeżego powietrza",
        "Description[pt]": "Uma brisa de ar fresco",
        "Description[pt_BR]": "Um pouco de ar fresco",
        "Description[ro]": "O gură de aer proaspăt",
        "Description[ru]": "Волшебные пузырьки",
        "Description[sl]": "Vdih svežega zraka",
        "Description[sv]": "Ett friskt andetag",
        "Description[tr]": "Temiz hava",
        "Description[uk]": "Ковток свіжого повітря",
        "Description[vi]": "Một luồng không khí trong lành",
        "Description[x-test]": "xxA breath of fresh airxx",
        "Description[zh_CN]": "如清新空气般淡雅的主题",
        "EnabledByDefault": true,
        "Id": "air",
        "License": "GPL",
        "Name": "Air",
        "Name[az]": "Air",
        "Name[be]": "Air",
        "Name[bg]": "Air",
        "Name[ca@valencia]": "Air",
        "Name[ca]": "Air",
        "Name[cs]": "Vzduch",
        "Name[de]": "Air",
        "Name[en_GB]": "Air",
        "Name[eo]": "Aero",
        "Name[es]": "Aire",
        "Name[eu]": "Airea",
        "Name[fi]": "Ilma",
        "Name[fr]": "Air",
        "Name[gl]": "Air",
        "Name[ia]": "Air",
        "Name[id]": "Air",
        "Name[it]": "Aria",
        "Name[ka]": "ჰაერი",
        "Name[ko]": "공기",
        "Name[nl]": "Air",
        "Name[nn]": "Luft",
        "Name[pl]": "Powietrze",
        "Name[pt]": "Ar",
        "Name[pt_BR]": "Air",
        "Name[ro]": "Aer",
        "Name[ru]": "Air",
        "Name[sl]": "Zrak",
        "Name[sv]": "Luft",
        "Name[tr]": "Hava",
        "Name[uk]": "Повітря",
        "Name[vi]": "Air",
        "Name[x-test]": "xxAirxx",
        "Name[zh_CN]": "Air 净空",
        "Version": "@KF_VERSION@",
        "Website": "https://plasma.kde.org"
    },
    "X-Plasma-API": "5.0"
}

==> plasma-framework-5.114.0.tar.xz: plasma-framework-5.114.0/src/desktoptheme/air/metadata.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "kde-artists@kde.org",
                "Name": "The Oxygen Project",
                "Name[az]": "Oxygen layihəsi",
                "Name[be]": "Праект \"Oxygen\"",
                "Name[bg]": "Проектът Oxygen",
                "Name[ca@valencia]": "El projecte Oxygen",
                "Name[ca]": "The Oxygen Project",
                "Name[cs]": "Projekt Oxygen",
                "Name[de]": "Das Oxygen-Projekt",
                "Name[en_GB]": "The Oxygen Project",
                "Name[eo]": "La Oksigeno-Projekto",
                "Name[es]": "El proyecto Oxígeno",
                "Name[eu]": "«Oxygen» proiektua",
                "Name[fi]": "Oxygen-projekti",
                "Name[fr]": "Le projet « Oxygen »",
                "Name[gl]": "O proxecto Osíxeno",
                "Name[ia]": "Le projecto Oxigen",
                "Name[id]": "The Oxygen Project",
                "Name[it]": "Il progetto Oxygen",
                "Name[ka]": "The Oxygen Project",
                "Name[ko]": "The Oxygen Project",
                "Name[nl]": "Het project Oxygen",
                "Name[nn]": "Oxygen-prosjektet",
                "Name[pl]": "Projekt Tlenu",
                "Name[pt]": "O Projecto Oxygen",
                "Name[pt_BR]": "O projeto Oxygen",
                "Name[ru]": "Проект Oxygen",
                "Name[sl]": "Projekt kisik",
                "Name[sv]": "Oxygen-projektet",
                "Name[tr]": "Oksijen Projesi",
                "Name[uk]": "Проєкт Oxygen",
                "Name[vi]": "Dự án Oxygen",
                "Name[x-test]": "xxThe Oxygen Projectxx",
                "Name[zh_CN]": "Oxygen 项目"
            }
        ],
        "Category": "",
        "Description": "A breath of fresh air",
        "Description[az]": "Bir nəfəs təmiz hava",
        "Description[be]": "Глыток свежага паветра",
        "Description[bg]": "Глътка свеж въздух",
        "Description[ca@valencia]": "Una alenada d'aire fresc",
        "Description[ca]": "Una alenada d'aire fresc",
        "Description[cs]": "Závan čerstvého vzduchu",
        "Description[en_GB]": "A breath of fresh air",
        "Description[eo]": "Spiro de freŝa aero",
        "Description[es]": "Un soplo de aire fresco",
        "Description[eu]": "Haize freskoa arnastea",
        "Description[fi]": "Raikkaan ilman henkäys",
        "Description[fr]": "Une bouffée d'air frais",
        "Description[gl]": "Un folgo de ar fresco.",
        "Description[ia]": "Un respiration de aere fresc",
        "Description[id]": "A breath of fresh air",
        "Description[it]": "Una ventata di aria fresca",
        "Description[ka]": "სუფთა ჰაერის ჩასუნთქვა",
        "Description[ko]": "신선한 바람",
        "Description[nl]": "Een hap frisse lucht",
        "Description[nn]": "Eit friskt pust",
        "Description[pl]": "Powiew świeżego powietrza",
        "Description[pt]": "Uma brisa de ar fresco",
        "Description[pt_BR]": "Um pouco de ar fresco",
        "Description[ro]": "O gură de aer proaspăt",
        "Description[ru]": "Волшебные пузырьки",
        "Description[sl]": "Vdih svežega zraka",
        "Description[sv]": "Ett friskt andetag",
        "Description[tr]": "Temiz hava",
        "Description[uk]": "Ковток свіжого повітря",
        "Description[vi]": "Một luồng không khí trong lành",
        "Description[x-test]": "xxA breath of fresh airxx",
        "Description[zh_CN]": "如清新空气般淡雅的主题",
        "EnabledByDefault": true,
        "Id": "air",
        "License": "GPL",
        "Name": "Air",
        "Name[az]": "Air",
        "Name[be]": "Air",
        "Name[bg]": "Air",
        "Name[ca@valencia]": "Air",
        "Name[ca]": "Air",
        "Name[cs]": "Vzduch",
        "Name[de]": "Air",
        "Name[en_GB]": "Air",
        "Name[eo]": "Aero",
        "Name[es]": "Aire",
        "Name[eu]": "Airea",
        "Name[fi]": "Ilma",
        "Name[fr]": "Air",
        "Name[gl]": "Air",
        "Name[ia]": "Air",
        "Name[id]": "Air",
        "Name[it]": "Aria",
        "Name[ka]": "ჰაერი",
        "Name[ko]": "공기",
        "Name[nl]": "Air",
        "Name[nn]": "Luft",
        "Name[pl]": "Powietrze",
        "Name[pt]": "Ar",
        "Name[pt_BR]": "Air",
        "Name[ro]": "Aer",
        "Name[ru]": "Air",
        "Name[sl]": "Zrak",
        "Name[sv]": "Luft",
        "Name[tr]": "Hava",
        "Name[uk]": "Повітря",
        "Name[vi]": "Air",
        "Name[x-test]": "xxAirxx",
        "Name[zh_CN]": "Air 净空",
        "Version": "@KF_VERSION@",
        "Website": "https://plasma.kde.org"
    },
    "X-Plasma-API": "5.0"
}
